@@ -39,13 +39,13 @@ class Q_DECL_EXPORT Existing_window_condition : public QObject, public Condition
 public:
     Existing_window_condition(Windowdef_list *window_P, Condition_list_base *parent = nullptr);
     Existing_window_condition(KConfigGroup &cfg_P, Condition_list_base *parent_P);
-    virtual ~Existing_window_condition();
-    bool match() const Q_DECL_OVERRIDE;
-    void cfg_write(KConfigGroup &cfg_P) const Q_DECL_OVERRIDE;
+    ~Existing_window_condition() override;
+    bool match() const override;
+    void cfg_write(KConfigGroup &cfg_P) const override;
     const Windowdef_list *window() const;
     Windowdef_list *window();
-    Existing_window_condition *copy() const Q_DECL_OVERRIDE;
-    const QString description() const Q_DECL_OVERRIDE;
+    Existing_window_condition *copy() const override;
+    const QString description() const override;
 public Q_SLOTS:
     void window_added(WId w_P);
     void window_removed(WId w_P);
